@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* plugins-config.c: plugins configuration */
@@ -270,7 +269,7 @@ plugin_config_read ()
                 pos = strchr (line, '=');
                 if (pos == NULL)
                 {
-                    irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+                    irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
                     gui_printf (NULL,
                                 _("%s %s, line %d: invalid syntax, missing \"=\"\n"),
                                 WEECHAT_WARNING, filename, line_number);
@@ -359,7 +358,7 @@ plugin_config_write ()
     
     if ((file = fopen (filename, "w")) == NULL)
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL, _("%s cannot create file \"%s\"\n"),
                     WEECHAT_ERROR, filename);
         free (filename);
